@@ -90,7 +90,8 @@ class OcrFinish(QWidget, Ui_OcrFinish):
     ProcessBar_signal = pyqtSignal(float)
     WidgetColorSignal = pyqtSignal(str)
     def __init__(self, communication=None, token = ""):
-        super(OcrFinish, self).__init__(communication)
+        # super(OcrFinish, self).__init__(communication)
+        super().__init__(communication)
         self.setupUi(self)
         self.setStyleSheet(style)
         self.OcrPath = ""
